@@ -3,16 +3,17 @@
 # revised 7 July, 2021
 # author：Haoxue Wang (haoxwang@student.ethz.ch)
 
-#' splitknockoff.select
+#' split knockoff selector given W statistics
 #'
 #' @param W statistics W_j for testing null hypothesis
 #' @param q target FDR
+#' @param option option$method can be 'knockoff' or 'knockoff+'
 #'
 #' @return S array of selected variable indices
-#' @usage splitknockoff.select(W, q)
+#' @usage sk.select(W, q, option)
 #' @export
 #'
-splitknockoff.select<-function(W, q){
+sk.select<-function(W, q, option){
 
   #  Inputs:
   #     W - statistics W_j for testing null hypothesis beta_j = 0.
@@ -20,13 +21,17 @@ splitknockoff.select<-function(W, q){
   #
   #   Outputs:
   #       S - array of selected variable indices
+  plus = 0
+  if (all.equal(option$method, 'knockoff+') == TRUE){
+    plus = 1
+  }
   W <- t(W)
   t = sort(c(0,abs(W[W!=0])))
   ratio = matrix(0, 1, length(t))
   for (i in 1:length(t)){
-  ratio[i] = sum(W <= -t[i]) / max(1, sum(W >= t[i]))
+  ratio[i] = (plus + sum(W <= -t[i])) / max(1, sum(W >= t[i]))
   }
-  nindex <- which(ratio <= q & ratio!=0)
+  nindex <- which(ratio <= q)
   if(is.null(nindex)==TRUE){
     T <- Inf
   }else{
